import { onMount } from "solid-js";
import { Chart, registerShape } from '@antv/g2';
// import DataSet from '@antv/data-set';

import utils from "../../../utils/index"
import "../../../assets/style/CommonBigScreenHome.css"


// 绘制原型柱状图
registerShape('point', 'circular', {
    // 1. 定义关键点
    getPoints(cfg) {
        const x = cfg.x;
        const y = cfg.y;
        const width = cfg.size;
        return [
            { x: x - width / 2, y },
            { x, y: y + width * 2 },
            { x: x + width / 2, y },
            { x, y: y - width * 2 },
        ];
    },
    // 2. 绘制
    draw(cfg, group) {
        const points = this.parsePoints(cfg.points); // 将0-1空间的坐标转换为画布坐标
        const polygon = group.addShape('path', {
            attrs: {
                path: [
                    ['M', points[0].x, points[0].y],
                    ['L', points[1].x, points[1].y],
                    ['L', points[2].x, points[2].y],
                    ['L', points[3].x, points[3].y],
                ],
            },
        });
        return polygon;
    },
})

function ListeningRate(prop) {
    let $canvas = undefined;
    function TrendChart(width, height, $canvas) {
        const data = prop.list.map(v => {
            return {
                type: v.platform,
                value: v.playCount
            }
        }).reverse();
        const chart = new Chart({
            container: $canvas,
            width: width - 20,
            height,
            padding: [ 10 , 60 , 10 , 60]
        });
        chart.data(data);
        chart.axis('value', false);
        chart.axis('type', {
            title: null,
            tickLine: null,
            subTickLine: null,
            line: null,
            label: {
                style: {
                    fill: "#fff"
                },
                formatter: () => {
                    return ""
                }
            }
        });
        // chart.tooltip({
        //     shared: true,
        //     itemTpl: `
        //     <div style="margin-bottom: 10px;list-style:none;">
        //         <span style="background-color:{color};" class="g2-tooltip-marker"></span>
        //         {value}
        //     </div>
        //     `
        // })
        chart.tooltip(false)
        chart.legend(false);
        chart.coordinate().transpose();
        chart
            .interval()
            .position('type*value')
            .color('l(0) 0:rgb(52,211,220); 1:rgba(52,211,220,0.6);');
        // 添加文本标注
        data.forEach((item) => {
            chart
                .annotation()
                .text({
                    position: [item.type, item.value],
                    content: item.type,
                    style: {
                        textAlign: 'center',
                        fill: '#fff',
                    },
                    offsetX: 30,
                });

            chart
                .annotation()
                .text({
                    position: [item.type, item.value],
                    content: utils.formatNum(item.value, 2),
                    style: {
                        textAlign: 'center',
                        fill: '#fff',
                    },
                    offsetX: -30,
                });
        });
        chart.point().position('type*value').shape('circular');
        chart.render();
    }
    onMount(() => {
        TrendChart(prop.width, prop.height - 30, $canvas)
    })
    return (
        <div class="livRang" style={{
            height: `${prop.height}px`,
            width: `${prop.width}px`
        }}>
            <div class="head">{prop.title}</div>
            <div ref={$canvas}></div>
        </div>
    );
}

export default ListeningRate;